==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythweb/modules/weather/handler.php <==
<?php
/**
 * Handler for the Weather module.
 *
 * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/modules/weather/handler.php $
 * @date        $Date: 2006-04-02 03:40:11 -0400 (Sun, 02 Apr 2006) $
 * @version     $Revision: 9601 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Weather
 *
/**/

// Unit preference
    if (empty($_SESSION['siunits'])) {
        $_SESSION['siunits'] = setting('SIUnits');
    }

/**
 * @global  array   $GLOBALS['Weather_Types']
 * @name    $Weather_Types
/**/
    global $Weather_Types;
    $Weather_Types = array();

// Load the weather data
    foreach (file(modules_path.'/'.module.'/weathertypes.dat') as $line) {
        list($id, $name, $img) = explode(',', $line);
        $Weather_Types[$id] = array($img, $name);
    }

// Build a list of the known weather sites
    $WeatherSites = array();

    $sh = $db->query('SELECT data, hostname FROM settings WHERE value="locale"');
    while (list($data, $host) = $sh->fetch_row()) {
    // New data site
        if (empty($WeatherSites[$data])) {
            $WeatherSites[$data] = new WeatherSite($data, $hostname, $_SESSION['siunits']);
        }
    // Add the hostname to sites we've already seen
        else {
            $WeatherSites[$data]->host .= ', '.$host;
        }

    }
    $sh->finish();

// Print the weather page template
    require_once tmpl_dir.'weather.php';

// Exit
    exit;

class WeatherSite {

    var $acid;
    var $host;

    var $city;
    var $subdiv;
    var $country;
    var $region;

    var $use_metric;
    var $Temperature;
    var $CIcon;
    var $ConditionImage;
    var $ConditionText;
    var $WindSpeed;
    var $WindDirection;
    var $BarometricPressure;
    var $Humidity;
    var $Real;
    var $UV;
    var $Visibility;
    var $ConText;
    var $Forecast;

    var $RadarImage;

    var $LastUpdated;

    function WeatherSite($data, $hostname, $use_metric) {
        $this->acid       = $data;
        $this->host       = $hostname;
        $this->use_metric = $use_metric;

        $this->getData();
        $this->RadarImage = $this->getRadarURL();
    }

    function getData() {
    $data = file("http://www.msnbc.com/m/chnk/d/weather_d_src.asp?acid=" . $this->acid);

    foreach($data as $line) {
        if(strpos($line, "this.sw") === false)
        continue;
        if(strpos($line, "swTempCel") !== false)
        continue;

        $line = trim($line);
        list($name, $value) = explode(" = \"", $line);
        $name = substr($name, 7);
        $value = substr($value, 0, strlen($value) - 2);

        switch ($name) {
        case "City":
            $this->city = $value;
            break;

        case "SubDiv":
            $this->subdiv = $value;
            break;

        case "Country":
            $this->country = $value;
            break;

        case "Region":
            $this->region = $value;
            break;

        case "Temp":
            $this->Temperature = $value;
            break;

        case "CIcon":
            $this->CIcon = $value;
            break;

        case "WindS":
            $this->WindSpeed = $value;
            break;

        case "WindD":
            $this->WindDirection = $value;
            break;

        case "Baro":
            $this->BarometricPressure = $value;
            break;

        case "Humid":
            $this->Humidity = $value;
            break;

        case "Real":
            $this->Real = $value;
            break;

        case "UV":
            $this->UV = $value;
            break;

        case "Vis":
            $this->Visibility = $value;
            break;

        case "LastUp":
            $this->LastUpdated = $value;
            break;

        case "ConText":
            $this->ConText = $value;
            break;

        case "Fore":
            $this->Forecast = $this->readForecast($value);
            break;

        default:
           // Weird, unknown type
           break;
        }
    }

    //Are we using metric or imperial system
    if($this->use_metric == "YES") {
        $this->Temperature = round((5/9) * ($this->Temperature - 32));
        $this->Real = round((5/9) * ($this->Real - 32));
        $this->BarometricPressure = round($this->BarometricPressure * 2.54);
        $this->Visibility = round($this->Visibility * 1.609344);
        $this->WindSpeed = round($this->WindSpeed * 1.609344);
    }

    if(strlen($this->ConText) > 0) {
        $this->ConditionText = $this->ConText;
        $this->ConditionImage = getImageFromName($this->ConditionText);
        if(strlen($this->ConditionImage) == 0)
        list($this->ConditionImage, $blah) = getImageAndDescFromId($this->CIcon);
    } else {
        list($this->ConditionImage, $this->ConditionText) = getImageAndDescFromId($this->CIcon);
    }
    $this->ConditionImage = (strlen($this->ConditionImage) > 0) ? $this->ConditionImage : "unknown.png";
    }

    function getRadarURL() {
    $data = file("http://w3.weather.com/weather/map/" . $this->acid . "?from=LAPmaps&setcookie=1");
    foreach($data as $line) {
        if(substr(trim($line), 0, 29) != "if (isMinNS4) var mapNURL = \"") continue;

        $url1 = substr(trim($line), 30);
        $url1 = "http://w3.weather.com/" . substr($url1, 0, strlen($url1) - 2);

        break;
    }

    $data = file($url1);
    foreach($data as $line) {
        if(substr(trim($line), 0, 48) != "<IMG NAME=\"mapImg\" SRC=\"http://image.weather.com") continue;

        $url2 = substr(trim($line), 24);
        $url2 = substr($url2, 0, strpos($url2, '"'));
        break;
    }
    return $url2;
    }

    function readForecast($data) {
    $ret = array();

    $data = explode("|", $data);
    for($i = 0;$i<5;$i++) {
	# mktime uses 0-6;  msnbc gives us 1-7;  adjust msnbc to match mktime
	$dayofweek = $data[$i] - 1;
        $forecast = new Forecast($data[5 + $i],$dayofweek);
        $forecast->dayofweek = $dayofweek;
        list($forecast->DescImage,$forecast->DescText) = getImageAndDescFromId($data[15 + $i]);
        $forecast->DescImage = (strlen($forecast->DescImage) > 0) ? $forecast->DescImage : "unknown.png";
        $forecast->DescText = (strlen($forecast->DescText) > 0) ? $forecast->DescText : t('Unknown') . " (" . $data[15+$i] . ")";
        if($this->use_metric == "YES") {
            $forecast->HighTemperature = round((5/9) * ($data[20 + $i] - 32));
            $forecast->LowTemperature = round((5/9) * ($data[40 + $i] -32 ));
        } else {
        $forecast->HighTemperature = $data[20 + $i];
        $forecast->LowTemperature = $data[40 + $i];
        }

        $ret[$i] = $forecast;
    }

    return $ret;
    }
}

function getImageAndDescFromId($my_id) {
    global $Weather_Types;
    return $Weather_Types[$my_id];
}

function getImageFromName($my_name) {
    global $Weather_Types;
    foreach ($Weather_Types as $pair) {
        if ($pair[1] == $my_name)
            return $pair[0];
    }
}

class Forecast {
    var $date;
    var $dayofweek;

    var $DescImage;
    var $DescText;

    var $HighTemperature;
    var $LowTemperature;

    function Forecast($date,$real_dayofweek) {

    $month = substr($date,0,2);
    $day = substr($date,3,2);
    $year = substr($date,6,4);

    $temp_date = mktime(0,0,0,$month,$day,$year);
    $date_time_array = getdate( $temp_date );
    $claimed_dayofweek = $date_time_array['wday'];

    if($real_dayofweek != $claimed_dayofweek)

        $this->date = date("m/d/Y", mktime(0, 0, 0, $month  , $day+1, $year));
    else
        $this->date = $date;
    }
}

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythweb/modules/weather/handler.php <==
<?php
/**
 * Handler for the Weather module.
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/weather/handler.php $
 * @date        $Date: 2007-05-28 04:11:56 -0500 (Mon, 28 May 2007) $
 * @version     $Revision: 13528 $
 * @author      $Author: stuartm $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  Weather
 *
/**/

// Unit preference
    if (empty($_SESSION['siunits'])) {
        $_SESSION['siunits'] = setting('SIUnits');
    }

/**
 * @global  array   $GLOBALS['Weather_Types']
 * @name    $Weather_Types
/**/
    global $Weather_Types;
    $Weather_Types = array();

// Load the weather data
    foreach (file(modules_path.'/'.module.'/weathertypes.dat') as $line) {
        list($id, $name, $img) = explode(',', $line);
        $Weather_Types[$id] = array($img, $name);
    }

// Build a list of the known weather sites
    $WeatherSites = array();

    $sh = $db->query('SELECT data, hostname FROM settings WHERE value="locale"');
    while (list($data, $host) = $sh->fetch_row()) {
    // New data site
        if (empty($WeatherSites[$data])) {
            $WeatherSites[$data] = new WeatherSite($data, $hostname, $_SESSION['siunits']);
        }
    // Add the hostname to sites we've already seen
        else {
            $WeatherSites[$data]->host .= ', '.$host;
        }

    }
    $sh->finish();

// Print the weather page template
    require_once tmpl_dir.'weather.php';

// Exit
    exit;

class WeatherSite {

    var $acid;
    var $host;

    var $city;
    var $subdiv;
    var $country;
    var $region;

    var $use_metric;
    var $Temperature;
    var $CIcon;
    var $ConditionImage;
    var $ConditionText;
    var $WindSpeed;
    var $WindDirection;
    var $BarometricPressure;
    var $Humidity;
    var $Real;
    var $UV;
    var $Visibility;
    var $ConText;
    var $Forecast;

    var $RadarImage;

    var $LastUpdated;

    function WeatherSite($data, $hostname, $use_metric) {
        $this->acid       = $data;
        $this->host       = $hostname;
        $this->use_metric = $use_metric;

        $this->getData();
        $this->RadarImage = $this->getRadarURL();
    }

    function getData() {
    $data = file("http://www.msnbc.com/m/chnk/d/weather_d_src.asp?acid=" . $this->acid);

    foreach($data as $line) {
        if(strpos($line, "this.sw") === false)
        continue;
        if(strpos($line, "swTempCel") !== false)
        continue;

        $line = trim($line);
        list($name, $value) = explode(" = \"", $line);
        $name = substr($name, 7);
        $value = substr($value, 0, strlen($value) - 2);

        switch ($name) {
        case "City":
            $this->city = $value;
            break;

        case "SubDiv":
            $this->subdiv = $value;
            break;

        case "Country":
            $this->country = $value;
            break;

        case "Region":
            $this->region = $value;
            break;

        case "Temp":
            $this->Temperature = $value;
            break;

        case "CIcon":
            $this->CIcon = $value;
            break;

        case "WindS":
            $this->WindSpeed = $value;
            break;

        case "WindD":
            $this->WindDirection = $value;
            break;

        case "Baro":
            $this->BarometricPressure = $value;
            break;

        case "Humid":
            $this->Humidity = $value;
            break;

        case "Real":
            $this->Real = $value;
            break;

        case "UV":
            $this->UV = $value;
            break;

        case "Vis":
            $this->Visibility = $value;
            break;

        case "LastUp":
            $this->LastUpdated = $value;
            break;

        case "ConText":
            $this->ConText = $value;
            break;

        case "Fore":
            $this->Forecast = $this->readForecast($value);
            break;

        default:
           // Weird, unknown type
           break;
        }
    }

    //Are we using metric or imperial system
    if($this->use_metric == "YES") {
        $this->Temperature = round((5/9) * ($this->Temperature - 32));
        $this->Real = round((5/9) * ($this->Real - 32));
        $this->BarometricPressure = round($this->BarometricPressure * 2.54);
        $this->Visibility = round($this->Visibility * 1.609344);
        $this->WindSpeed = round($this->WindSpeed * 1.609344);
    }

    if(strlen($this->ConText) > 0) {
        $this->ConditionText = $this->ConText;
        $this->ConditionImage = getImageFromName($this->ConditionText);
        if(strlen($this->ConditionImage) == 0)
        list($this->ConditionImage, $blah) = getImageAndDescFromId($this->CIcon);
    } else {
        list($this->ConditionImage, $this->ConditionText) = getImageAndDescFromId($this->CIcon);
    }
    $this->ConditionImage = (strlen($this->ConditionImage) > 0) ? $this->ConditionImage : "unknown.png";
    }

    function getRadarURL() {
    @$data = file("http://w3.weather.com/weather/map/" . $this->acid . "?from=LAPmaps&setcookie=1");
    if (is_array($data) && count($data)) {
        foreach($data as $line) {
            if(substr(trim($line), 0, 29) != "if (isMinNS4) var mapNURL = \"") continue;

            $url1 = substr(trim($line), 30);
            $url1 = "http://w3.weather.com/" . substr($url1, 0, strlen($url1) - 2);

            break;
        }
    }

    $data = file($url1);
    if (is_array($data) && count($data)) {
        foreach($data as $line) {
            if(substr(trim($line), 0, 48) != "<IMG NAME=\"mapImg\" SRC=\"http://image.weather.com") continue;

            $url2 = substr(trim($line), 24);
            $url2 = substr($url2, 0, strpos($url2, '"'));
            break;
        }
    }
    return $url2;
    }

    function readForecast($data) {
    $ret = array();

    $data = explode("|", $data);
    for($i = 0;$i<5;$i++) {
	# mktime uses 0-6;  msnbc gives us 1-7;  adjust msnbc to match mktime
	$dayofweek = $data[$i] - 1;
        $forecast = new Forecast($data[5 + $i],$dayofweek);
        $forecast->dayofweek = $dayofweek;
        list($forecast->DescImage,$forecast->DescText) = getImageAndDescFromId($data[15 + $i]);
        $forecast->DescImage = (strlen($forecast->DescImage) > 0) ? $forecast->DescImage : "unknown.png";
        $forecast->DescText = (strlen($forecast->DescText) > 0) ? $forecast->DescText : t('Unknown') . " (" . $data[15+$i] . ")";
        if($this->use_metric == "YES") {
            $forecast->HighTemperature = round((5/9) * ($data[20 + $i] - 32));
            $forecast->LowTemperature = round((5/9) * ($data[40 + $i] -32 ));
        } else {
        $forecast->HighTemperature = $data[20 + $i];
        $forecast->LowTemperature = $data[40 + $i];
        }

        $ret[$i] = $forecast;
    }

    return $ret;
    }
}

function getImageAndDescFromId($my_id) {
    global $Weather_Types;
    return $Weather_Types[$my_id];
}

function getImageFromName($my_name) {
    global $Weather_Types;
    foreach ($Weather_Types as $pair) {
        if ($pair[1] == $my_name)
            return $pair[0];
    }
}

class Forecast {
    var $date;
    var $dayofweek;

    var $DescImage;
    var $DescText;

    var $HighTemperature;
    var $LowTemperature;

    function Forecast($date,$real_dayofweek) {

    $month = substr($date,0,2);
    $day = substr($date,3,2);
    $year = substr($date,6,4);

    $temp_date = mktime(0,0,0,$month,$day,$year);
    $date_time_array = getdate( $temp_date );
    $claimed_dayofweek = $date_time_array['wday'];

    if($real_dayofweek != $claimed_dayofweek)

        $this->date = date("m/d/Y", mktime(0, 0, 0, $month  , $day+1, $year));
    else
        $this->date = $date;
    }
}
